@@ -1,4 +1,9 @@
-from .Gaussiandistribution import Gaussian
-from .Binomialdistribution import Binomial
+import os
+import sys
 
-# TODO: import the Binomial class from the Binomialdistribution module
\ No newline at end of file
+from .Binomialdistribution import Binomial
+from .Gaussiandistribution import Gaussian
+
+sys.path.append(os.path.dirname(os.path.realpath(__file__)))
+
+# TODO: import the Binomial class from the Binomialdistribution module
